Example Pig job
===============

This script trims spaces in input text

This sample pig job is based on examples in Chapter 11 of
"Hadoop: The Definitive Guide" by Tom White, published by O'Reilly Media.
The original code can be found in a maven project at

https://github.com/tomwhite/hadoop-book

